game_qu.base.colors API documentation
Description: Has many RGB colors, but these colors do not have to be used as any RGB color works with drawing shapes

# Module `game_qu.base.colors`

Has many RGB colors, but these colors do not have to be used as any RGB color works with drawing shapes

Expand source code

    """Has many RGB colors, but these colors do not have to be used as any RGB color works with drawing shapes"""

    # Gives the RGB values for the colors below
    white = [255, 255, 255]
    light_gray = [190, 190, 190]
    gray = [127, 127, 127]
    dark_gray = [63, 63, 63]
    black = [0, 0, 0]
    red = [255, 0, 0]
    green = [0, 255, 0]
    blue = [0, 0, 255]
    yellow = [255, 255, 0]
    magenta = [255, 0, 255]
    cyan = [0, 255, 255]
    orange = [255, 100, 0]
    purple = [75, 0, 130]
    medium_green = [0, 100, 0]
    pleasing_green = [51, 178, 73]
    brown = [150, 75, 0]